@@ -1,7 +1,8 @@
 from svarga import db
 from opster import command
 from sqlalchemy import MetaData, exc
-from migrate.versioning import schema, repository, exceptions
+from migrate import exceptions
+from migrate.versioning import schema, repository
 
 from svargaext.sqlamigrate import apps, codegen, files, utils
 
